from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation.Metadata
class AgileAttribute(Structure):
    pass
class AlsoUsableForAttribute(Structure):
    otherType: String
class AnsiAttribute(Structure):
    pass
Architecture = Int32
None_: win32more.Windows.Win32.Foundation.Metadata.Architecture = 0
X86: win32more.Windows.Win32.Foundation.Metadata.Architecture = 1
X64: win32more.Windows.Win32.Foundation.Metadata.Architecture = 2
Arm64: win32more.Windows.Win32.Foundation.Metadata.Architecture = 4
All: win32more.Windows.Win32.Foundation.Metadata.Architecture = 7
class AssociatedConstantAttribute(Structure):
    Name: String
class AssociatedEnumAttribute(Structure):
    Name: String
class CanReturnErrorsAsSuccessAttribute(Structure):
    pass
class CanReturnMultipleSuccessValuesAttribute(Structure):
    pass
class ComOutPtrAttribute(Structure):
    pass
class ConstAttribute(Structure):
    pass
class ConstantAttribute(Structure):
    Value: String
class CppAttributeList(Structure):
    AttributeList: String
class DoNotReleaseAttribute(Structure):
    pass
class DocumentationAttribute(Structure):
    Uri: String
class FlexibleArrayAttribute(Structure):
    pass
class FreeWithAttribute(Structure):
    Name: String
class GuidAttribute(Structure):
    a: UInt32
    b: UInt16
    c: UInt16
    d: Byte
    e: Byte
    f: Byte
    g: Byte
    h: Byte
    i: Byte
    j: Byte
    k: Byte
class IgnoreIfReturnAttribute(Structure):
    Value: String
class InvalidHandleValueAttribute(Structure):
    Value: Int64
class MemorySizeAttribute(Structure):
    pass
class MetadataTypedefAttribute(Structure):
    pass
class NativeArrayInfoAttribute(Structure):
    pass
class NativeBitfieldAttribute(Structure):
    name: String
    offset: Int64
    length: Int64
class NativeEncodingAttribute(Structure):
    Name: String
class NativeInheritanceAttribute(Structure):
    BaseName: String
class NativeTypeNameAttribute(Structure):
    Name: String
class NativeTypedefAttribute(Structure):
    pass
class NotNullTerminatedAttribute(Structure):
    pass
class NullNullTerminatedAttribute(Structure):
    pass
class RAIIFreeAttribute(Structure):
    Name: String
class ReservedAttribute(Structure):
    pass
class RetValAttribute(Structure):
    pass
class RetainedAttribute(Structure):
    pass
class ScopedEnumAttribute(Structure):
    pass
class StaticLibraryAttribute(Structure):
    LibName: String
class StructSizeFieldAttribute(Structure):
    field: String
class SupportedArchitectureAttribute(Structure):
    arch: win32more.Windows.Win32.Foundation.Metadata.Architecture
class SupportedOSPlatformAttribute(Structure):
    platform: String
class UnicodeAttribute(Structure):
    pass


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.Windows.Widgets.Feeds.Providers
import win32more.Microsoft.Windows.Widgets.Notifications
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class CustomQueryParametersRequestedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersRequestedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersRequestedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersRequestedArgs) -> WinRT_String: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class CustomQueryParametersUpdateOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptions
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptionsFactory, feedProviderDefinitionId: WinRT_String, customQueryParameters: WinRT_String) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions: ...
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_CustomQueryParameters(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptions) -> WinRT_String: ...
    CustomQueryParameters = property(get_CustomQueryParameters, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedAnalyticsInfoReportedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedAnalyticsInfoReportedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AnalyticsJson(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs) -> WinRT_String: ...
    AnalyticsJson = property(get_AnalyticsJson, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedDisabledArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedDisabledArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedDisabledArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedDisabledArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedDisabledArgs) -> WinRT_String: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedEnabledArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedEnabledArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedEnabledArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedEnabledArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedEnabledArgs) -> WinRT_String: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedErrorInfoReportedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedErrorInfoReportedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ErrorJson(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs) -> WinRT_String: ...
    ErrorJson = property(get_ErrorJson, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedManager'
    @winrt_mixinmethod
    def GetEnabledFeedProviders(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager) -> ReceiveArray[win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderInfo]: ...
    @winrt_mixinmethod
    def SetCustomQueryParameters(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager, options: win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions) -> Void: ...
    @winrt_mixinmethod
    def SendMessageToContent(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager2, feedProviderDefinitionId: WinRT_String, feedDefinitionId: WinRT_String, message: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def TryShowAnnouncement(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager2, feedProviderDefinitionId: WinRT_String, feedDefinitionId: WinRT_String, announcement: win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement) -> Void: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManagerStatics) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedManager: ...
class FeedMessageReceivedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedMessageReceivedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs) -> WinRT_String: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
    Message = property(get_Message, None)
class FeedProviderDisabledArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderDisabledArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderDisabledArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderDisabledArgs) -> WinRT_String: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedProviderEnabledArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderEnabledArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderEnabledArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderEnabledArgs) -> WinRT_String: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedProviderInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderInfo
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderInfo'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_EnabledFeedDefinitionIds(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderInfo) -> ReceiveArray[WinRT_String]: ...
    EnabledFeedDefinitionIds = property(get_EnabledFeedDefinitionIds, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedResourceRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequest'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Method(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Method(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_Headers(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest) -> win32more.Windows.Foundation.Collections.StringMap: ...
    @winrt_mixinmethod
    def put_Headers(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest, value: win32more.Windows.Foundation.Collections.StringMap) -> Void: ...
    Content = property(get_Content, put_Content)
    Headers = property(get_Headers, put_Headers)
    Method = property(get_Method, put_Method)
    Uri = property(get_Uri, None)
class FeedResourceRequestedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequestedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Request(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequest: ...
    @winrt_mixinmethod
    def get_Response(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse: ...
    @winrt_mixinmethod
    def put_Response(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs, value: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> win32more.Windows.Foundation.Deferral: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
    Request = property(get_Request, None)
    Response = property(get_Response, put_Response)
class FeedResourceResponse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponseFactory, content: win32more.Windows.Storage.Streams.IRandomAccessStreamReference, reasonPhrase: WinRT_String, statusCode: Int32) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def get_Headers(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse) -> win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]: ...
    @winrt_mixinmethod
    def put_Headers(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]) -> Void: ...
    @winrt_mixinmethod
    def get_ReasonPhrase(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_StatusCode(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse) -> Int32: ...
    Content = property(get_Content, None)
    Headers = property(get_Headers, put_Headers)
    ReasonPhrase = property(get_ReasonPhrase, None)
    StatusCode = property(get_StatusCode, None)
class ICustomQueryParametersRequestedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersRequestedArgs'
    _iid_ = Guid('{dc2b0cd8-7936-5346-9371-b21484c7d859}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class ICustomQueryParametersUpdateOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptions'
    _iid_ = Guid('{753f1177-4909-568a-b070-98a3139205ec}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_CustomQueryParameters(self) -> WinRT_String: ...
    CustomQueryParameters = property(get_CustomQueryParameters, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class ICustomQueryParametersUpdateOptionsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptionsFactory'
    _iid_ = Guid('{34e318cd-3884-53c0-911c-225f32228fae}')
    @winrt_commethod(6)
    def CreateInstance(self, feedProviderDefinitionId: WinRT_String, customQueryParameters: WinRT_String) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions: ...
class IFeedAnalyticsInfoReportedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs'
    _iid_ = Guid('{3c0e3d65-ed47-5b8a-b650-39a7edf18942}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AnalyticsJson(self) -> WinRT_String: ...
    AnalyticsJson = property(get_AnalyticsJson, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedAnnouncementInvokedTarget(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnnouncementInvokedTarget'
    _iid_ = Guid('{5d44ae2a-072c-4df9-9fe5-34d5d2e9ff63}')
    @winrt_commethod(6)
    def OnAnnouncementInvoked(self, args: win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncementInvokedArgs) -> Void: ...
class IFeedDisabledArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedDisabledArgs'
    _iid_ = Guid('{95300612-aca7-53c0-9cf6-d803689132c1}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> WinRT_String: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedEnabledArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedEnabledArgs'
    _iid_ = Guid('{eff4b2d7-7347-5969-a77d-cac433f0fdae}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> WinRT_String: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedErrorInfoReportedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs'
    _iid_ = Guid('{62de018c-161e-52d0-9dbe-aec106fb6600}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ErrorJson(self) -> WinRT_String: ...
    ErrorJson = property(get_ErrorJson, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager'
    _iid_ = Guid('{87df6a84-15aa-45cb-8911-5cafab57f723}')
    @winrt_commethod(6)
    def GetEnabledFeedProviders(self) -> ReceiveArray[win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderInfo]: ...
    @winrt_commethod(7)
    def SetCustomQueryParameters(self, options: win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions) -> Void: ...
class IFeedManager2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager2'
    _iid_ = Guid('{5838300a-a069-455d-9943-ba078ada00d8}')
    @winrt_commethod(6)
    def SendMessageToContent(self, feedProviderDefinitionId: WinRT_String, feedDefinitionId: WinRT_String, message: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def TryShowAnnouncement(self, feedProviderDefinitionId: WinRT_String, feedDefinitionId: WinRT_String, announcement: win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement) -> Void: ...
class IFeedManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedManagerStatics'
    _iid_ = Guid('{4baf5174-77d6-5e2a-94ea-4f14ccdb1f2c}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedManager: ...
class IFeedMessageReceivedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs'
    _iid_ = Guid('{4ed6ecf9-4c74-5a0b-ae04-bef6dd776f8a}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Message(self) -> WinRT_String: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
    Message = property(get_Message, None)
class IFeedProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProvider'
    _iid_ = Guid('{7293a12b-0329-458d-ac25-5332be478fde}')
    @winrt_commethod(6)
    def OnFeedProviderEnabled(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderEnabledArgs) -> Void: ...
    @winrt_commethod(7)
    def OnFeedProviderDisabled(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderDisabledArgs) -> Void: ...
    @winrt_commethod(8)
    def OnFeedEnabled(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedEnabledArgs) -> Void: ...
    @winrt_commethod(9)
    def OnFeedDisabled(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedDisabledArgs) -> Void: ...
    @winrt_commethod(10)
    def OnCustomQueryParametersRequested(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersRequestedArgs) -> Void: ...
class IFeedProviderAnalytics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderAnalytics'
    _iid_ = Guid('{f6885791-3085-4bd7-9cb1-4f1354c3a687}')
    @winrt_commethod(6)
    def OnAnalyticsInfoReported(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedAnalyticsInfoReportedArgs) -> Void: ...
class IFeedProviderDisabledArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderDisabledArgs'
    _iid_ = Guid('{19b65aec-e01d-5e8c-ab5f-324212e7cd30}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedProviderEnabledArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderEnabledArgs'
    _iid_ = Guid('{821fc9af-0de6-5a9b-9ae6-e179117b40e4}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedProviderErrors(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderErrors'
    _iid_ = Guid('{6611e00a-d86c-49a3-9381-b7da67ee62dc}')
    @winrt_commethod(6)
    def OnErrorInfoReported(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedErrorInfoReportedArgs) -> Void: ...
class IFeedProviderInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderInfo'
    _iid_ = Guid('{73c37049-3c03-5896-8532-f9dfdaeb723f}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_EnabledFeedDefinitionIds(self) -> ReceiveArray[WinRT_String]: ...
    EnabledFeedDefinitionIds = property(get_EnabledFeedDefinitionIds, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedProviderMessage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderMessage'
    _iid_ = Guid('{60c2442a-4c9d-4880-ba26-caca9e567dd4}')
    @winrt_commethod(6)
    def OnMessageReceived(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedMessageReceivedArgs) -> Void: ...
class IFeedResourceProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceProvider'
    _iid_ = Guid('{e1b6266d-88a0-416c-9440-e341cb047cd3}')
    @winrt_commethod(6)
    def OnResourceRequested(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequestedArgs) -> Void: ...
class IFeedResourceRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest'
    _iid_ = Guid('{e62e479c-e21f-5863-b4c9-df1be2227981}')
    @winrt_commethod(6)
    def get_Uri(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Method(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Method(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Content(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(10)
    def put_Content(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(11)
    def get_Headers(self) -> win32more.Windows.Foundation.Collections.StringMap: ...
    @winrt_commethod(12)
    def put_Headers(self, value: win32more.Windows.Foundation.Collections.StringMap) -> Void: ...
    Content = property(get_Content, put_Content)
    Headers = property(get_Headers, put_Headers)
    Method = property(get_Method, put_Method)
    Uri = property(get_Uri, None)
class IFeedResourceRequestedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs'
    _iid_ = Guid('{360eb709-0bc9-52c1-9c70-3c7d413173d8}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Request(self) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequest: ...
    @winrt_commethod(9)
    def get_Response(self) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse: ...
    @winrt_commethod(10)
    def put_Response(self, value: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse) -> Void: ...
    @winrt_commethod(11)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
    Request = property(get_Request, None)
    Response = property(get_Response, put_Response)
class IFeedResourceResponse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse'
    _iid_ = Guid('{f831824e-7aef-53fc-b7ee-32ade675a3ad}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(7)
    def get_Headers(self) -> win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]: ...
    @winrt_commethod(8)
    def put_Headers(self, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]) -> Void: ...
    @winrt_commethod(9)
    def get_ReasonPhrase(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_StatusCode(self) -> Int32: ...
    Content = property(get_Content, None)
    Headers = property(get_Headers, put_Headers)
    ReasonPhrase = property(get_ReasonPhrase, None)
    StatusCode = property(get_StatusCode, None)
class IFeedResourceResponseFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponseFactory'
    _iid_ = Guid('{db01690d-2547-5d7a-b625-d1629f443c5c}')
    @winrt_commethod(6)
    def CreateInstance(self, content: win32more.Windows.Storage.Streams.IRandomAccessStreamReference, reasonPhrase: WinRT_String, statusCode: Int32) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Recovery
import win32more.Windows.Win32.System.WindowsProgramming
@winfunctype('KERNEL32.dll')
def RegisterApplicationRecoveryCallback(pRecoveyCallback: win32more.Windows.Win32.System.WindowsProgramming.APPLICATION_RECOVERY_CALLBACK, pvParameter: VoidPtr, dwPingInterval: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def UnregisterApplicationRecoveryCallback() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def RegisterApplicationRestart(pwzCommandline: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: win32more.Windows.Win32.System.Recovery.REGISTER_APPLICATION_RESTART_FLAGS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def UnregisterApplicationRestart() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def GetApplicationRecoveryCallback(hProcess: win32more.Windows.Win32.Foundation.HANDLE, pRecoveryCallback: POINTER(win32more.Windows.Win32.System.WindowsProgramming.APPLICATION_RECOVERY_CALLBACK), ppvParameter: POINTER(VoidPtr), pdwPingInterval: POINTER(UInt32), pdwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def GetApplicationRestartSettings(hProcess: win32more.Windows.Win32.Foundation.HANDLE, pwzCommandline: win32more.Windows.Win32.Foundation.PWSTR, pcchSize: POINTER(UInt32), pdwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def ApplicationRecoveryInProgress(pbCancelled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def ApplicationRecoveryFinished(bSuccess: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
REGISTER_APPLICATION_RESTART_FLAGS = UInt32
RESTART_NO_CRASH: win32more.Windows.Win32.System.Recovery.REGISTER_APPLICATION_RESTART_FLAGS = 1
RESTART_NO_HANG: win32more.Windows.Win32.System.Recovery.REGISTER_APPLICATION_RESTART_FLAGS = 2
RESTART_NO_PATCH: win32more.Windows.Win32.System.Recovery.REGISTER_APPLICATION_RESTART_FLAGS = 4
RESTART_NO_REBOOT: win32more.Windows.Win32.System.Recovery.REGISTER_APPLICATION_RESTART_FLAGS = 8


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Globalization
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Media.Ocr
import win32more.Windows.Win32.System.WinRT
class IOcrEngine(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Ocr.IOcrEngine'
    _iid_ = Guid('{5a14bc41-5b76-3140-b680-8825562683ac}')
    @winrt_commethod(6)
    def RecognizeAsync(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Ocr.OcrResult]: ...
    @winrt_commethod(7)
    def get_RecognizerLanguage(self) -> win32more.Windows.Globalization.Language: ...
    RecognizerLanguage = property(get_RecognizerLanguage, None)
class IOcrEngineStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Ocr.IOcrEngineStatics'
    _iid_ = Guid('{5bffa85a-3384-3540-9940-699120d428a8}')
    @winrt_commethod(6)
    def get_MaxImageDimension(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_AvailableRecognizerLanguages(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Globalization.Language]: ...
    @winrt_commethod(8)
    def IsLanguageSupported(self, language: win32more.Windows.Globalization.Language) -> Boolean: ...
    @winrt_commethod(9)
    def TryCreateFromLanguage(self, language: win32more.Windows.Globalization.Language) -> win32more.Windows.Media.Ocr.OcrEngine: ...
    @winrt_commethod(10)
    def TryCreateFromUserProfileLanguages(self) -> win32more.Windows.Media.Ocr.OcrEngine: ...
    AvailableRecognizerLanguages = property(get_AvailableRecognizerLanguages, None)
    MaxImageDimension = property(get_MaxImageDimension, None)
class IOcrLine(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Ocr.IOcrLine'
    _iid_ = Guid('{0043a16f-e31f-3a24-899c-d444bd088124}')
    @winrt_commethod(6)
    def get_Words(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Ocr.OcrWord]: ...
    @winrt_commethod(7)
    def get_Text(self) -> WinRT_String: ...
    Text = property(get_Text, None)
    Words = property(get_Words, None)
class IOcrResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Ocr.IOcrResult'
    _iid_ = Guid('{9bd235b2-175b-3d6a-92e2-388c206e2f63}')
    @winrt_commethod(6)
    def get_Lines(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Ocr.OcrLine]: ...
    @winrt_commethod(7)
    def get_TextAngle(self) -> win32more.Windows.Foundation.IReference[Double]: ...
    @winrt_commethod(8)
    def get_Text(self) -> WinRT_String: ...
    Lines = property(get_Lines, None)
    Text = property(get_Text, None)
    TextAngle = property(get_TextAngle, None)
class IOcrWord(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Ocr.IOcrWord'
    _iid_ = Guid('{3c2a477a-5cd9-3525-ba2a-23d1e0a68a1d}')
    @winrt_commethod(6)
    def get_BoundingRect(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(7)
    def get_Text(self) -> WinRT_String: ...
    BoundingRect = property(get_BoundingRect, None)
    Text = property(get_Text, None)
class _OcrEngine_Meta_(ComPtr.__class__):
    pass
class OcrEngine(ComPtr, metaclass=_OcrEngine_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Ocr.IOcrEngine
    _classid_ = 'Windows.Media.Ocr.OcrEngine'
    @winrt_mixinmethod
    def RecognizeAsync(self: win32more.Windows.Media.Ocr.IOcrEngine, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Ocr.OcrResult]: ...
    @winrt_mixinmethod
    def get_RecognizerLanguage(self: win32more.Windows.Media.Ocr.IOcrEngine) -> win32more.Windows.Globalization.Language: ...
    @winrt_classmethod
    def get_MaxImageDimension(cls: win32more.Windows.Media.Ocr.IOcrEngineStatics) -> UInt32: ...
    @winrt_classmethod
    def get_AvailableRecognizerLanguages(cls: win32more.Windows.Media.Ocr.IOcrEngineStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Globalization.Language]: ...
    @winrt_classmethod
    def IsLanguageSupported(cls: win32more.Windows.Media.Ocr.IOcrEngineStatics, language: win32more.Windows.Globalization.Language) -> Boolean: ...
    @winrt_classmethod
    def TryCreateFromLanguage(cls: win32more.Windows.Media.Ocr.IOcrEngineStatics, language: win32more.Windows.Globalization.Language) -> win32more.Windows.Media.Ocr.OcrEngine: ...
    @winrt_classmethod
    def TryCreateFromUserProfileLanguages(cls: win32more.Windows.Media.Ocr.IOcrEngineStatics) -> win32more.Windows.Media.Ocr.OcrEngine: ...
    RecognizerLanguage = property(get_RecognizerLanguage, None)
    _OcrEngine_Meta_.AvailableRecognizerLanguages = property(get_AvailableRecognizerLanguages, None)
    _OcrEngine_Meta_.MaxImageDimension = property(get_MaxImageDimension, None)
class OcrLine(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Ocr.IOcrLine
    _classid_ = 'Windows.Media.Ocr.OcrLine'
    @winrt_mixinmethod
    def get_Words(self: win32more.Windows.Media.Ocr.IOcrLine) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Ocr.OcrWord]: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.Media.Ocr.IOcrLine) -> WinRT_String: ...
    Text = property(get_Text, None)
    Words = property(get_Words, None)
class OcrResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Ocr.IOcrResult
    _classid_ = 'Windows.Media.Ocr.OcrResult'
    @winrt_mixinmethod
    def get_Lines(self: win32more.Windows.Media.Ocr.IOcrResult) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Ocr.OcrLine]: ...
    @winrt_mixinmethod
    def get_TextAngle(self: win32more.Windows.Media.Ocr.IOcrResult) -> win32more.Windows.Foundation.IReference[Double]: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.Media.Ocr.IOcrResult) -> WinRT_String: ...
    Lines = property(get_Lines, None)
    Text = property(get_Text, None)
    TextAngle = property(get_TextAngle, None)
class OcrWord(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Ocr.IOcrWord
    _classid_ = 'Windows.Media.Ocr.OcrWord'
    @winrt_mixinmethod
    def get_BoundingRect(self: win32more.Windows.Media.Ocr.IOcrWord) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.Media.Ocr.IOcrWord) -> WinRT_String: ...
    BoundingRect = property(get_BoundingRect, None)
    Text = property(get_Text, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Appointments
import win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider
import win32more.Windows.Foundation
import win32more.Windows.Win32.System.WinRT
class AddAppointmentOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAddAppointmentOperation
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.AddAppointmentOperation'
    @winrt_mixinmethod
    def get_AppointmentInformation(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAddAppointmentOperation) -> win32more.Windows.ApplicationModel.Appointments.Appointment: ...
    @winrt_mixinmethod
    def get_SourcePackageFamilyName(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAddAppointmentOperation) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompleted(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAddAppointmentOperation, itemId: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def ReportCanceled(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAddAppointmentOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportError(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAddAppointmentOperation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def DismissUI(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAddAppointmentOperation) -> Void: ...
    AppointmentInformation = property(get_AppointmentInformation, None)
    SourcePackageFamilyName = property(get_SourcePackageFamilyName, None)
class _AppointmentsProviderLaunchActionVerbs_Meta_(ComPtr.__class__):
    pass
class AppointmentsProviderLaunchActionVerbs(ComPtr, metaclass=_AppointmentsProviderLaunchActionVerbs_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.AppointmentsProviderLaunchActionVerbs'
    @winrt_classmethod
    def get_ShowAppointmentDetails(cls: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAppointmentsProviderLaunchActionVerbsStatics2) -> WinRT_String: ...
    @winrt_classmethod
    def get_AddAppointment(cls: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAppointmentsProviderLaunchActionVerbsStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_ReplaceAppointment(cls: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAppointmentsProviderLaunchActionVerbsStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_RemoveAppointment(cls: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAppointmentsProviderLaunchActionVerbsStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_ShowTimeFrame(cls: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IAppointmentsProviderLaunchActionVerbsStatics) -> WinRT_String: ...
    _AppointmentsProviderLaunchActionVerbs_Meta_.AddAppointment = property(get_AddAppointment, None)
    _AppointmentsProviderLaunchActionVerbs_Meta_.RemoveAppointment = property(get_RemoveAppointment, None)
    _AppointmentsProviderLaunchActionVerbs_Meta_.ReplaceAppointment = property(get_ReplaceAppointment, None)
    _AppointmentsProviderLaunchActionVerbs_Meta_.ShowAppointmentDetails = property(get_ShowAppointmentDetails, None)
    _AppointmentsProviderLaunchActionVerbs_Meta_.ShowTimeFrame = property(get_ShowTimeFrame, None)
class IAddAppointmentOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.IAddAppointmentOperation'
    _iid_ = Guid('{ec4a9af3-620d-4c69-add7-9794e918081f}')
    @winrt_commethod(6)
    def get_AppointmentInformation(self) -> win32more.Windows.ApplicationModel.Appointments.Appointment: ...
    @winrt_commethod(7)
    def get_SourcePackageFamilyName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def ReportCompleted(self, itemId: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def ReportCanceled(self) -> Void: ...
    @winrt_commethod(10)
    def ReportError(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(11)
    def DismissUI(self) -> Void: ...
    AppointmentInformation = property(get_AppointmentInformation, None)
    SourcePackageFamilyName = property(get_SourcePackageFamilyName, None)
class IAppointmentsProviderLaunchActionVerbsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.IAppointmentsProviderLaunchActionVerbsStatics'
    _iid_ = Guid('{36dbba28-9e2e-49c6-8ef7-3ab7a5dcc8b8}')
    @winrt_commethod(6)
    def get_AddAppointment(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ReplaceAppointment(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_RemoveAppointment(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_ShowTimeFrame(self) -> WinRT_String: ...
    AddAppointment = property(get_AddAppointment, None)
    RemoveAppointment = property(get_RemoveAppointment, None)
    ReplaceAppointment = property(get_ReplaceAppointment, None)
    ShowTimeFrame = property(get_ShowTimeFrame, None)
class IAppointmentsProviderLaunchActionVerbsStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.IAppointmentsProviderLaunchActionVerbsStatics2'
    _iid_ = Guid('{ef9049a4-af21-473c-88dc-76cd89f60ca5}')
    @winrt_commethod(6)
    def get_ShowAppointmentDetails(self) -> WinRT_String: ...
    ShowAppointmentDetails = property(get_ShowAppointmentDetails, None)
class IRemoveAppointmentOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation'
    _iid_ = Guid('{08b66aba-fe33-46cd-a50c-a8ffb3260537}')
    @winrt_commethod(6)
    def get_AppointmentId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_InstanceStartDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(8)
    def get_SourcePackageFamilyName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def ReportCompleted(self) -> Void: ...
    @winrt_commethod(10)
    def ReportCanceled(self) -> Void: ...
    @winrt_commethod(11)
    def ReportError(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def DismissUI(self) -> Void: ...
    AppointmentId = property(get_AppointmentId, None)
    InstanceStartDate = property(get_InstanceStartDate, None)
    SourcePackageFamilyName = property(get_SourcePackageFamilyName, None)
class IReplaceAppointmentOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation'
    _iid_ = Guid('{f4903d9b-9e61-4de2-a732-2687c07d1de8}')
    @winrt_commethod(6)
    def get_AppointmentId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_AppointmentInformation(self) -> win32more.Windows.ApplicationModel.Appointments.Appointment: ...
    @winrt_commethod(8)
    def get_InstanceStartDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(9)
    def get_SourcePackageFamilyName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def ReportCompleted(self, itemId: WinRT_String) -> Void: ...
    @winrt_commethod(11)
    def ReportCanceled(self) -> Void: ...
    @winrt_commethod(12)
    def ReportError(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(13)
    def DismissUI(self) -> Void: ...
    AppointmentId = property(get_AppointmentId, None)
    AppointmentInformation = property(get_AppointmentInformation, None)
    InstanceStartDate = property(get_InstanceStartDate, None)
    SourcePackageFamilyName = property(get_SourcePackageFamilyName, None)
class RemoveAppointmentOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.RemoveAppointmentOperation'
    @winrt_mixinmethod
    def get_AppointmentId(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InstanceStartDate(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_SourcePackageFamilyName(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompleted(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportCanceled(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportError(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def DismissUI(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IRemoveAppointmentOperation) -> Void: ...
    AppointmentId = property(get_AppointmentId, None)
    InstanceStartDate = property(get_InstanceStartDate, None)
    SourcePackageFamilyName = property(get_SourcePackageFamilyName, None)
class ReplaceAppointmentOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation
    _classid_ = 'Windows.ApplicationModel.Appointments.AppointmentsProvider.ReplaceAppointmentOperation'
    @winrt_mixinmethod
    def get_AppointmentId(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentInformation(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation) -> win32more.Windows.ApplicationModel.Appointments.Appointment: ...
    @winrt_mixinmethod
    def get_InstanceStartDate(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_SourcePackageFamilyName(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompleted(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation, itemId: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def ReportCanceled(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportError(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def DismissUI(self: win32more.Windows.ApplicationModel.Appointments.AppointmentsProvider.IReplaceAppointmentOperation) -> Void: ...
    AppointmentId = property(get_AppointmentId, None)
    AppointmentInformation = property(get_AppointmentInformation, None)
    InstanceStartDate = property(get_InstanceStartDate, None)
    SourcePackageFamilyName = property(get_SourcePackageFamilyName, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Media
import win32more.Windows.Media.FaceAnalysis
import win32more.Windows.Win32.System.WinRT
class DetectedFace(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.FaceAnalysis.IDetectedFace
    _classid_ = 'Windows.Media.FaceAnalysis.DetectedFace'
    @winrt_mixinmethod
    def get_FaceBox(self: win32more.Windows.Media.FaceAnalysis.IDetectedFace) -> win32more.Windows.Graphics.Imaging.BitmapBounds: ...
    FaceBox = property(get_FaceBox, None)
class _FaceDetector_Meta_(ComPtr.__class__):
    pass
class FaceDetector(ComPtr, metaclass=_FaceDetector_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.FaceAnalysis.IFaceDetector
    _classid_ = 'Windows.Media.FaceAnalysis.FaceDetector'
    @winrt_mixinmethod
    def DetectFacesAsync(self: win32more.Windows.Media.FaceAnalysis.IFaceDetector, image: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.FaceAnalysis.DetectedFace]]: ...
    @winrt_mixinmethod
    def DetectFacesWithSearchAreaAsync(self: win32more.Windows.Media.FaceAnalysis.IFaceDetector, image: win32more.Windows.Graphics.Imaging.SoftwareBitmap, searchArea: win32more.Windows.Graphics.Imaging.BitmapBounds) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.FaceAnalysis.DetectedFace]]: ...
    @winrt_mixinmethod
    def get_MinDetectableFaceSize(self: win32more.Windows.Media.FaceAnalysis.IFaceDetector) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_mixinmethod
    def put_MinDetectableFaceSize(self: win32more.Windows.Media.FaceAnalysis.IFaceDetector, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    @winrt_mixinmethod
    def get_MaxDetectableFaceSize(self: win32more.Windows.Media.FaceAnalysis.IFaceDetector) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_mixinmethod
    def put_MaxDetectableFaceSize(self: win32more.Windows.Media.FaceAnalysis.IFaceDetector, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Windows.Media.FaceAnalysis.IFaceDetectorStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.FaceAnalysis.FaceDetector]: ...
    @winrt_classmethod
    def GetSupportedBitmapPixelFormats(cls: win32more.Windows.Media.FaceAnalysis.IFaceDetectorStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Imaging.BitmapPixelFormat]: ...
    @winrt_classmethod
    def IsBitmapPixelFormatSupported(cls: win32more.Windows.Media.FaceAnalysis.IFaceDetectorStatics, bitmapPixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat) -> Boolean: ...
    @winrt_classmethod
    def get_IsSupported(cls: win32more.Windows.Media.FaceAnalysis.IFaceDetectorStatics) -> Boolean: ...
    MaxDetectableFaceSize = property(get_MaxDetectableFaceSize, put_MaxDetectableFaceSize)
    MinDetectableFaceSize = property(get_MinDetectableFaceSize, put_MinDetectableFaceSize)
    _FaceDetector_Meta_.IsSupported = property(get_IsSupported, None)
class _FaceTracker_Meta_(ComPtr.__class__):
    pass
class FaceTracker(ComPtr, metaclass=_FaceTracker_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.FaceAnalysis.IFaceTracker
    _classid_ = 'Windows.Media.FaceAnalysis.FaceTracker'
    @winrt_mixinmethod
    def ProcessNextFrameAsync(self: win32more.Windows.Media.FaceAnalysis.IFaceTracker, videoFrame: win32more.Windows.Media.VideoFrame) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.FaceAnalysis.DetectedFace]]: ...
    @winrt_mixinmethod
    def get_MinDetectableFaceSize(self: win32more.Windows.Media.FaceAnalysis.IFaceTracker) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_mixinmethod
    def put_MinDetectableFaceSize(self: win32more.Windows.Media.FaceAnalysis.IFaceTracker, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    @winrt_mixinmethod
    def get_MaxDetectableFaceSize(self: win32more.Windows.Media.FaceAnalysis.IFaceTracker) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_mixinmethod
    def put_MaxDetectableFaceSize(self: win32more.Windows.Media.FaceAnalysis.IFaceTracker, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Windows.Media.FaceAnalysis.IFaceTrackerStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.FaceAnalysis.FaceTracker]: ...
    @winrt_classmethod
    def GetSupportedBitmapPixelFormats(cls: win32more.Windows.Media.FaceAnalysis.IFaceTrackerStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Imaging.BitmapPixelFormat]: ...
    @winrt_classmethod
    def IsBitmapPixelFormatSupported(cls: win32more.Windows.Media.FaceAnalysis.IFaceTrackerStatics, bitmapPixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat) -> Boolean: ...
    @winrt_classmethod
    def get_IsSupported(cls: win32more.Windows.Media.FaceAnalysis.IFaceTrackerStatics) -> Boolean: ...
    MaxDetectableFaceSize = property(get_MaxDetectableFaceSize, put_MaxDetectableFaceSize)
    MinDetectableFaceSize = property(get_MinDetectableFaceSize, put_MinDetectableFaceSize)
    _FaceTracker_Meta_.IsSupported = property(get_IsSupported, None)
class IDetectedFace(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.FaceAnalysis.IDetectedFace'
    _iid_ = Guid('{8200d454-66bc-34df-9410-e89400195414}')
    @winrt_commethod(6)
    def get_FaceBox(self) -> win32more.Windows.Graphics.Imaging.BitmapBounds: ...
    FaceBox = property(get_FaceBox, None)
class IFaceDetector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.FaceAnalysis.IFaceDetector'
    _iid_ = Guid('{16b672dc-fe6f-3117-8d95-c3f04d51630c}')
    @winrt_commethod(6)
    def DetectFacesAsync(self, image: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.FaceAnalysis.DetectedFace]]: ...
    @winrt_commethod(7)
    def DetectFacesWithSearchAreaAsync(self, image: win32more.Windows.Graphics.Imaging.SoftwareBitmap, searchArea: win32more.Windows.Graphics.Imaging.BitmapBounds) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.FaceAnalysis.DetectedFace]]: ...
    @winrt_commethod(8)
    def get_MinDetectableFaceSize(self) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_commethod(9)
    def put_MinDetectableFaceSize(self, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    @winrt_commethod(10)
    def get_MaxDetectableFaceSize(self) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_commethod(11)
    def put_MaxDetectableFaceSize(self, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    MaxDetectableFaceSize = property(get_MaxDetectableFaceSize, put_MaxDetectableFaceSize)
    MinDetectableFaceSize = property(get_MinDetectableFaceSize, put_MinDetectableFaceSize)
class IFaceDetectorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.FaceAnalysis.IFaceDetectorStatics'
    _iid_ = Guid('{bc042d67-9047-33f6-881b-6746c1b218b8}')
    @winrt_commethod(6)
    def CreateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.FaceAnalysis.FaceDetector]: ...
    @winrt_commethod(7)
    def GetSupportedBitmapPixelFormats(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Imaging.BitmapPixelFormat]: ...
    @winrt_commethod(8)
    def IsBitmapPixelFormatSupported(self, bitmapPixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsSupported(self) -> Boolean: ...
    IsSupported = property(get_IsSupported, None)
class IFaceTracker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.FaceAnalysis.IFaceTracker'
    _iid_ = Guid('{6ba67d8c-a841-4420-93e6-2420a1884fcf}')
    @winrt_commethod(6)
    def ProcessNextFrameAsync(self, videoFrame: win32more.Windows.Media.VideoFrame) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.FaceAnalysis.DetectedFace]]: ...
    @winrt_commethod(7)
    def get_MinDetectableFaceSize(self) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_commethod(8)
    def put_MinDetectableFaceSize(self, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    @winrt_commethod(9)
    def get_MaxDetectableFaceSize(self) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_commethod(10)
    def put_MaxDetectableFaceSize(self, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    MaxDetectableFaceSize = property(get_MaxDetectableFaceSize, put_MaxDetectableFaceSize)
    MinDetectableFaceSize = property(get_MinDetectableFaceSize, put_MinDetectableFaceSize)
class IFaceTrackerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.FaceAnalysis.IFaceTrackerStatics'
    _iid_ = Guid('{e9629198-1801-3fa5-932e-31d767af6c4d}')
    @winrt_commethod(6)
    def CreateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.FaceAnalysis.FaceTracker]: ...
    @winrt_commethod(7)
    def GetSupportedBitmapPixelFormats(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Imaging.BitmapPixelFormat]: ...
    @winrt_commethod(8)
    def IsBitmapPixelFormatSupported(self, bitmapPixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsSupported(self) -> Boolean: ...
    IsSupported = property(get_IsSupported, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.System.Memory.NonVolatile
if ARCH in 'X64,ARM64':
    @winfunctype('ntdll.dll')
    def RtlGetNonVolatileToken(NvBuffer: VoidPtr, Size: UIntPtr, NvToken: POINTER(VoidPtr)) -> UInt32: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ntdll.dll')
    def RtlFreeNonVolatileToken(NvToken: VoidPtr) -> UInt32: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ntdll.dll')
    def RtlFlushNonVolatileMemory(NvToken: VoidPtr, NvBuffer: VoidPtr, Size: UIntPtr, Flags: UInt32) -> UInt32: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ntdll.dll')
    def RtlDrainNonVolatileFlush(NvToken: VoidPtr) -> UInt32: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ntdll.dll')
    def RtlWriteNonVolatileMemory(NvToken: VoidPtr, NvDestination: VoidPtr, Source: VoidPtr, Size: UIntPtr, Flags: UInt32) -> UInt32: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ntdll.dll')
    def RtlFillNonVolatileMemory(NvToken: VoidPtr, NvDestination: VoidPtr, Size: UIntPtr, Value: Byte, Flags: UInt32) -> UInt32: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ntdll.dll')
    def RtlFlushNonVolatileMemoryRanges(NvToken: VoidPtr, NvRanges: POINTER(win32more.Windows.Win32.System.Memory.NonVolatile.NV_MEMORY_RANGE), NumRanges: UIntPtr, Flags: UInt32) -> UInt32: ...
class NV_MEMORY_RANGE(Structure):
    BaseAddress: VoidPtr
    Length: UIntPtr


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.SerialCommunication
import win32more.Windows.Win32.Foundation
DEVPKEY_DeviceInterface_Serial_UsbVendorId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4c6bf15c-4c03-4aac-91f5-64c0f852bcf4}'), pid=2)
DEVPKEY_DeviceInterface_Serial_UsbProductId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4c6bf15c-4c03-4aac-91f5-64c0f852bcf4}'), pid=3)
DEVPKEY_DeviceInterface_Serial_PortName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4c6bf15c-4c03-4aac-91f5-64c0f852bcf4}'), pid=4)
IOCTL_SERIAL_SET_BAUD_RATE: UInt32 = 1769476
IOCTL_SERIAL_SET_QUEUE_SIZE: UInt32 = 1769480
IOCTL_SERIAL_SET_LINE_CONTROL: UInt32 = 1769484
IOCTL_SERIAL_SET_BREAK_ON: UInt32 = 1769488
IOCTL_SERIAL_SET_BREAK_OFF: UInt32 = 1769492
IOCTL_SERIAL_IMMEDIATE_CHAR: UInt32 = 1769496
IOCTL_SERIAL_SET_TIMEOUTS: UInt32 = 1769500
IOCTL_SERIAL_GET_TIMEOUTS: UInt32 = 1769504
IOCTL_SERIAL_SET_DTR: UInt32 = 1769508
IOCTL_SERIAL_CLR_DTR: UInt32 = 1769512
IOCTL_SERIAL_RESET_DEVICE: UInt32 = 1769516
IOCTL_SERIAL_SET_RTS: UInt32 = 1769520
IOCTL_SERIAL_CLR_RTS: UInt32 = 1769524
IOCTL_SERIAL_SET_XOFF: UInt32 = 1769528
IOCTL_SERIAL_SET_XON: UInt32 = 1769532
IOCTL_SERIAL_GET_WAIT_MASK: UInt32 = 1769536
IOCTL_SERIAL_SET_WAIT_MASK: UInt32 = 1769540
IOCTL_SERIAL_WAIT_ON_MASK: UInt32 = 1769544
IOCTL_SERIAL_PURGE: UInt32 = 1769548
IOCTL_SERIAL_GET_BAUD_RATE: UInt32 = 1769552
IOCTL_SERIAL_GET_LINE_CONTROL: UInt32 = 1769556
IOCTL_SERIAL_GET_CHARS: UInt32 = 1769560
IOCTL_SERIAL_SET_CHARS: UInt32 = 1769564
IOCTL_SERIAL_GET_HANDFLOW: UInt32 = 1769568
IOCTL_SERIAL_SET_HANDFLOW: UInt32 = 1769572
IOCTL_SERIAL_GET_MODEMSTATUS: UInt32 = 1769576
IOCTL_SERIAL_GET_COMMSTATUS: UInt32 = 1769580
IOCTL_SERIAL_XOFF_COUNTER: UInt32 = 1769584
IOCTL_SERIAL_GET_PROPERTIES: UInt32 = 1769588
IOCTL_SERIAL_GET_DTRRTS: UInt32 = 1769592
IOCTL_SERIAL_CONFIG_SIZE: UInt32 = 1769600
IOCTL_SERIAL_GET_COMMCONFIG: UInt32 = 1769604
IOCTL_SERIAL_SET_COMMCONFIG: UInt32 = 1769608
IOCTL_SERIAL_GET_STATS: UInt32 = 1769612
IOCTL_SERIAL_CLEAR_STATS: UInt32 = 1769616
IOCTL_SERIAL_GET_MODEM_CONTROL: UInt32 = 1769620
IOCTL_SERIAL_SET_MODEM_CONTROL: UInt32 = 1769624
IOCTL_SERIAL_SET_FIFO_CONTROL: UInt32 = 1769628
IOCTL_SERIAL_APPLY_DEFAULT_CONFIGURATION: UInt32 = 1769632
IOCTL_SERIAL_SET_INTERVAL_TIMER_RESOLUTION: UInt32 = 1769636
IOCTL_SERIAL_INTERNAL_DO_WAIT_WAKE: UInt32 = 1769476
IOCTL_SERIAL_INTERNAL_CANCEL_WAIT_WAKE: UInt32 = 1769480
IOCTL_SERIAL_INTERNAL_BASIC_SETTINGS: UInt32 = 1769484
IOCTL_SERIAL_INTERNAL_RESTORE_SETTINGS: UInt32 = 1769488
SERIAL_EV_RXCHAR: UInt32 = 1
SERIAL_EV_RXFLAG: UInt32 = 2
SERIAL_EV_TXEMPTY: UInt32 = 4
SERIAL_EV_CTS: UInt32 = 8
SERIAL_EV_DSR: UInt32 = 16
SERIAL_EV_RLSD: UInt32 = 32
SERIAL_EV_BREAK: UInt32 = 64
SERIAL_EV_ERR: UInt32 = 128
SERIAL_EV_RING: UInt32 = 256
SERIAL_EV_PERR: UInt32 = 512
SERIAL_EV_RX80FULL: UInt32 = 1024
SERIAL_EV_EVENT1: UInt32 = 2048
SERIAL_EV_EVENT2: UInt32 = 4096
SERIAL_PURGE_TXABORT: UInt32 = 1
SERIAL_PURGE_RXABORT: UInt32 = 2
SERIAL_PURGE_TXCLEAR: UInt32 = 4
SERIAL_PURGE_RXCLEAR: UInt32 = 8
STOP_BIT_1: UInt32 = 0
STOP_BITS_1_5: UInt32 = 1
STOP_BITS_2: UInt32 = 2
NO_PARITY: UInt32 = 0
ODD_PARITY: UInt32 = 1
EVEN_PARITY: UInt32 = 2
MARK_PARITY: UInt32 = 3
SPACE_PARITY: UInt32 = 4
SERIAL_LSRMST_ESCAPE: UInt16 = 0
SERIAL_LSRMST_LSR_DATA: UInt16 = 1
SERIAL_LSRMST_LSR_NODATA: UInt16 = 2
SERIAL_LSRMST_MST: UInt16 = 3
IOCTL_INTERNAL_SERENUM_REMOVE_SELF: UInt32 = 3604999
COMDB_MIN_PORTS_ARBITRATED: UInt32 = 256
COMDB_MAX_PORTS_ARBITRATED: UInt32 = 4096
CDB_REPORT_BITS: UInt32 = 0
CDB_REPORT_BYTES: UInt32 = 1
@winfunctype('MSPORTS.dll')
def ComDBOpen(PHComDB: POINTER(win32more.Windows.Win32.Devices.SerialCommunication.HCOMDB)) -> Int32: ...
@winfunctype('MSPORTS.dll')
def ComDBClose(HComDB: win32more.Windows.Win32.Devices.SerialCommunication.HCOMDB) -> Int32: ...
@winfunctype('MSPORTS.dll')
def ComDBGetCurrentPortUsage(HComDB: win32more.Windows.Win32.Devices.SerialCommunication.HCOMDB, Buffer: POINTER(Byte), BufferSize: UInt32, ReportType: UInt32, MaxPortsReported: POINTER(UInt32)) -> Int32: ...
@winfunctype('MSPORTS.dll')
def ComDBClaimNextFreePort(HComDB: win32more.Windows.Win32.Devices.SerialCommunication.HCOMDB, ComNumber: POINTER(UInt32)) -> Int32: ...
@winfunctype('MSPORTS.dll')
def ComDBClaimPort(HComDB: win32more.Windows.Win32.Devices.SerialCommunication.HCOMDB, ComNumber: UInt32, ForceClaim: win32more.Windows.Win32.Foundation.BOOL, Forced: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Int32: ...
@winfunctype('MSPORTS.dll')
def ComDBReleasePort(HComDB: win32more.Windows.Win32.Devices.SerialCommunication.HCOMDB, ComNumber: UInt32) -> Int32: ...
@winfunctype('MSPORTS.dll')
def ComDBResizeDatabase(HComDB: win32more.Windows.Win32.Devices.SerialCommunication.HCOMDB, NewSize: UInt32) -> Int32: ...
HCOMDB = VoidPtr
@winfunctype_pointer
def PSERENUM_READPORT(SerPortAddress: VoidPtr) -> Byte: ...
@winfunctype_pointer
def PSERENUM_WRITEPORT(SerPortAddress: VoidPtr, Value: Byte) -> Void: ...
SERENUM_PORTION = Int32
SerenumFirstHalf: win32more.Windows.Win32.Devices.SerialCommunication.SERENUM_PORTION = 0
SerenumSecondHalf: win32more.Windows.Win32.Devices.SerialCommunication.SERENUM_PORTION = 1
SerenumWhole: win32more.Windows.Win32.Devices.SerialCommunication.SERENUM_PORTION = 2
class SERENUM_PORT_DESC(Structure):
    Size: UInt32
    PortHandle: VoidPtr
    PortAddress: Int64
    Reserved: UInt16 * 1
class SERENUM_PORT_PARAMETERS(Structure):
    Size: UInt32
    ReadAccessor: win32more.Windows.Win32.Devices.SerialCommunication.PSERENUM_READPORT
    WriteAccessor: win32more.Windows.Win32.Devices.SerialCommunication.PSERENUM_WRITEPORT
    SerPortAddress: VoidPtr
    HardwareHandle: VoidPtr
    Portion: win32more.Windows.Win32.Devices.SerialCommunication.SERENUM_PORTION
    NumberAxis: UInt16
    Reserved: UInt16 * 3
class SERIALCONFIG(Structure):
    Size: UInt32
    Version: UInt16
    SubType: UInt32
    ProvOffset: UInt32
    ProviderSize: UInt32
    ProviderData: Char * 1
class SERIALPERF_STATS(Structure):
    ReceivedCount: UInt32
    TransmittedCount: UInt32
    FrameErrorCount: UInt32
    SerialOverrunErrorCount: UInt32
    BufferOverrunErrorCount: UInt32
    ParityErrorCount: UInt32
class SERIAL_BASIC_SETTINGS(Structure):
    Timeouts: win32more.Windows.Win32.Devices.SerialCommunication.SERIAL_TIMEOUTS
    HandFlow: win32more.Windows.Win32.Devices.SerialCommunication.SERIAL_HANDFLOW
    RxFifo: UInt32
    TxFifo: UInt32
class SERIAL_BAUD_RATE(Structure):
    BaudRate: UInt32
class SERIAL_CHARS(Structure):
    EofChar: Byte
    ErrorChar: Byte
    BreakChar: Byte
    EventChar: Byte
    XonChar: Byte
    XoffChar: Byte
class SERIAL_COMMPROP(Structure):
    PacketLength: UInt16
    PacketVersion: UInt16
    ServiceMask: UInt32
    Reserved1: UInt32
    MaxTxQueue: UInt32
    MaxRxQueue: UInt32
    MaxBaud: UInt32
    ProvSubType: UInt32
    ProvCapabilities: UInt32
    SettableParams: UInt32
    SettableBaud: UInt32
    SettableData: UInt16
    SettableStopParity: UInt16
    CurrentTxQueue: UInt32
    CurrentRxQueue: UInt32
    ProvSpec1: UInt32
    ProvSpec2: UInt32
    ProvChar: Char * 1
class SERIAL_HANDFLOW(Structure):
    ControlHandShake: UInt32
    FlowReplace: UInt32
    XonLimit: Int32
    XoffLimit: Int32
class SERIAL_LINE_CONTROL(Structure):
    StopBits: Byte
    Parity: Byte
    WordLength: Byte
class SERIAL_QUEUE_SIZE(Structure):
    InSize: UInt32
    OutSize: UInt32
class SERIAL_STATUS(Structure):
    Errors: UInt32
    HoldReasons: UInt32
    AmountInInQueue: UInt32
    AmountInOutQueue: UInt32
    EofReceived: win32more.Windows.Win32.Foundation.BOOLEAN
    WaitForImmediate: win32more.Windows.Win32.Foundation.BOOLEAN
class SERIAL_TIMEOUTS(Structure):
    ReadIntervalTimeout: UInt32
    ReadTotalTimeoutMultiplier: UInt32
    ReadTotalTimeoutConstant: UInt32
    WriteTotalTimeoutMultiplier: UInt32
    WriteTotalTimeoutConstant: UInt32
class SERIAL_XOFF_COUNTER(Structure):
    Timeout: UInt32
    Counter: Int32
    XoffChar: Byte


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.IO
@winfunctype('KERNEL32.dll')
def CreateIoCompletionPort(FileHandle: win32more.Windows.Win32.Foundation.HANDLE, ExistingCompletionPort: win32more.Windows.Win32.Foundation.HANDLE, CompletionKey: UIntPtr, NumberOfConcurrentThreads: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def GetQueuedCompletionStatus(CompletionPort: win32more.Windows.Win32.Foundation.HANDLE, lpNumberOfBytesTransferred: POINTER(UInt32), lpCompletionKey: POINTER(UIntPtr), lpOverlapped: POINTER(POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)), dwMilliseconds: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetQueuedCompletionStatusEx(CompletionPort: win32more.Windows.Win32.Foundation.HANDLE, lpCompletionPortEntries: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED_ENTRY), ulCount: UInt32, ulNumEntriesRemoved: POINTER(UInt32), dwMilliseconds: UInt32, fAlertable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def PostQueuedCompletionStatus(CompletionPort: win32more.Windows.Win32.Foundation.HANDLE, dwNumberOfBytesTransferred: UInt32, dwCompletionKey: UIntPtr, lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def DeviceIoControl(hDevice: win32more.Windows.Win32.Foundation.HANDLE, dwIoControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetOverlappedResult(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED), lpNumberOfBytesTransferred: POINTER(UInt32), bWait: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CancelIoEx(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CancelIo(hFile: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetOverlappedResultEx(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED), lpNumberOfBytesTransferred: POINTER(UInt32), dwMilliseconds: UInt32, bAlertable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CancelSynchronousIo(hThread: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def BindIoCompletionCallback(FileHandle: win32more.Windows.Win32.Foundation.HANDLE, Function: win32more.Windows.Win32.System.IO.LPOVERLAPPED_COMPLETION_ROUTINE, Flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
class IO_STATUS_BLOCK(Structure):
    Anonymous: _Anonymous_e__Union
    Information: UIntPtr
    class _Anonymous_e__Union(Union):
        Status: win32more.Windows.Win32.Foundation.NTSTATUS
        Pointer: VoidPtr
@winfunctype_pointer
def LPOVERLAPPED_COMPLETION_ROUTINE(dwErrorCode: UInt32, dwNumberOfBytesTransfered: UInt32, lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)) -> Void: ...
class OVERLAPPED(Structure):
    Internal: UIntPtr
    InternalHigh: UIntPtr
    Anonymous: _Anonymous_e__Union
    hEvent: win32more.Windows.Win32.Foundation.HANDLE
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        Pointer: VoidPtr
        class _Anonymous_e__Struct(Structure):
            Offset: UInt32
            OffsetHigh: UInt32
class OVERLAPPED_ENTRY(Structure):
    lpCompletionKey: UIntPtr
    lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)
    Internal: UIntPtr
    dwNumberOfBytesTransferred: UInt32
@winfunctype_pointer
def PIO_APC_ROUTINE(ApcContext: VoidPtr, IoStatusBlock: POINTER(win32more.Windows.Win32.System.IO.IO_STATUS_BLOCK), Reserved: UInt32) -> Void: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Services.TargetedContent
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class ITargetedContentAction(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentAction'
    _iid_ = Guid('{d75b691e-6cd6-4ca0-9d8f-4728b0b7e6b6}')
    @winrt_commethod(6)
    def InvokeAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
class ITargetedContentAvailabilityChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentAvailabilityChangedEventArgs'
    _iid_ = Guid('{e0f59d26-5927-4450-965c-1ceb7becde65}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class ITargetedContentChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentChangedEventArgs'
    _iid_ = Guid('{99d488c9-587e-4586-8ef7-b54ca9453a16}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    @winrt_commethod(7)
    def get_HasPreviousContentExpired(self) -> Boolean: ...
    HasPreviousContentExpired = property(get_HasPreviousContentExpired, None)
class ITargetedContentCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentCollection'
    _iid_ = Guid('{2d4b66c5-f163-44ba-9f6e-e1a4c2bb559d}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def ReportInteraction(self, interaction: win32more.Windows.Services.TargetedContent.TargetedContentInteraction) -> Void: ...
    @winrt_commethod(8)
    def ReportCustomInteraction(self, customInteractionName: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Path(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Services.TargetedContent.TargetedContentValue]: ...
    @winrt_commethod(11)
    def get_Collections(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentCollection]: ...
    @winrt_commethod(12)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentItem]: ...
    Collections = property(get_Collections, None)
    Id = property(get_Id, None)
    Items = property(get_Items, None)
    Path = property(get_Path, None)
    Properties = property(get_Properties, None)
class ITargetedContentContainer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentContainer'
    _iid_ = Guid('{bc2494c9-8837-47c2-850f-d79d64595926}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Timestamp(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(8)
    def get_Availability(self) -> win32more.Windows.Services.TargetedContent.TargetedContentAvailability: ...
    @winrt_commethod(9)
    def get_Content(self) -> win32more.Windows.Services.TargetedContent.TargetedContentCollection: ...
    @winrt_commethod(10)
    def SelectSingleObject(self, path: WinRT_String) -> win32more.Windows.Services.TargetedContent.TargetedContentObject: ...
    Availability = property(get_Availability, None)
    Content = property(get_Content, None)
    Id = property(get_Id, None)
    Timestamp = property(get_Timestamp, None)
class ITargetedContentContainerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentContainerStatics'
    _iid_ = Guid('{5b47e7fb-2140-4c1f-a736-c59583f227d8}')
    @winrt_commethod(6)
    def GetAsync(self, contentId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.TargetedContent.TargetedContentContainer]: ...
class ITargetedContentImage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentImage'
    _iid_ = Guid('{a7a585d9-779f-4b1e-bbb1-8eaf53fbeab2}')
    @winrt_commethod(6)
    def get_Height(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_Width(self) -> UInt32: ...
    Height = property(get_Height, None)
    Width = property(get_Width, None)
class ITargetedContentItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentItem'
    _iid_ = Guid('{38168dc4-276c-4c32-96ba-565c6e406e74}')
    @winrt_commethod(6)
    def get_Path(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def ReportInteraction(self, interaction: win32more.Windows.Services.TargetedContent.TargetedContentInteraction) -> Void: ...
    @winrt_commethod(8)
    def ReportCustomInteraction(self, customInteractionName: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_State(self) -> win32more.Windows.Services.TargetedContent.TargetedContentItemState: ...
    @winrt_commethod(10)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Services.TargetedContent.TargetedContentValue]: ...
    @winrt_commethod(11)
    def get_Collections(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentCollection]: ...
    Collections = property(get_Collections, None)
    Path = property(get_Path, None)
    Properties = property(get_Properties, None)
    State = property(get_State, None)
class ITargetedContentItemState(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentItemState'
    _iid_ = Guid('{73935454-4c65-4b47-a441-472de53c79b6}')
    @winrt_commethod(6)
    def get_ShouldDisplay(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_AppInstallationState(self) -> win32more.Windows.Services.TargetedContent.TargetedContentAppInstallationState: ...
    AppInstallationState = property(get_AppInstallationState, None)
    ShouldDisplay = property(get_ShouldDisplay, None)
class ITargetedContentObject(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentObject'
    _iid_ = Guid('{041d7969-2212-42d1-9dfa-88a8e3033aa3}')
    @winrt_commethod(6)
    def get_ObjectKind(self) -> win32more.Windows.Services.TargetedContent.TargetedContentObjectKind: ...
    @winrt_commethod(7)
    def get_Collection(self) -> win32more.Windows.Services.TargetedContent.TargetedContentCollection: ...
    @winrt_commethod(8)
    def get_Item(self) -> win32more.Windows.Services.TargetedContent.TargetedContentItem: ...
    @winrt_commethod(9)
    def get_Value(self) -> win32more.Windows.Services.TargetedContent.TargetedContentValue: ...
    Collection = property(get_Collection, None)
    Item = property(get_Item, None)
    ObjectKind = property(get_ObjectKind, None)
    Value = property(get_Value, None)
class ITargetedContentStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentStateChangedEventArgs'
    _iid_ = Guid('{9a1cef3d-8073-4416-8df2-546835a6414f}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class ITargetedContentSubscription(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentSubscription'
    _iid_ = Guid('{882c2c49-c652-4c7a-acad-1f7fa2986c73}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetContentContainerAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.TargetedContent.TargetedContentContainer]: ...
    @winrt_commethod(8)
    def add_ContentChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.TargetedContent.TargetedContentSubscription, win32more.Windows.Services.TargetedContent.TargetedContentChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_ContentChanged(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_AvailabilityChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.TargetedContent.TargetedContentSubscription, win32more.Windows.Services.TargetedContent.TargetedContentAvailabilityChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_AvailabilityChanged(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.TargetedContent.TargetedContentSubscription, win32more.Windows.Services.TargetedContent.TargetedContentStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_StateChanged(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Id = property(get_Id, None)
    ContentChanged = event()
    AvailabilityChanged = event()
    StateChanged = event()
class ITargetedContentSubscriptionOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentSubscriptionOptions'
    _iid_ = Guid('{61ee6ad0-2c83-421b-8467-413eaf1aeb97}')
    @winrt_commethod(6)
    def get_SubscriptionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_AllowPartialContentAvailability(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_AllowPartialContentAvailability(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def get_CloudQueryParameters(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_commethod(10)
    def get_LocalFilters(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_commethod(11)
    def Update(self) -> Void: ...
    AllowPartialContentAvailability = property(get_AllowPartialContentAvailability, put_AllowPartialContentAvailability)
    CloudQueryParameters = property(get_CloudQueryParameters, None)
    LocalFilters = property(get_LocalFilters, None)
    SubscriptionId = property(get_SubscriptionId, None)
class ITargetedContentSubscriptionStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentSubscriptionStatics'
    _iid_ = Guid('{faddfe80-360d-4916-b53c-7ea27090d02a}')
    @winrt_commethod(6)
    def GetAsync(self, subscriptionId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.TargetedContent.TargetedContentSubscription]: ...
    @winrt_commethod(7)
    def GetOptions(self, subscriptionId: WinRT_String) -> win32more.Windows.Services.TargetedContent.TargetedContentSubscriptionOptions: ...
class ITargetedContentValue(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.TargetedContent.ITargetedContentValue'
    _iid_ = Guid('{aafde4b3-4215-4bf8-867f-43f04865f9bf}')
    @winrt_commethod(6)
    def get_ValueKind(self) -> win32more.Windows.Services.TargetedContent.TargetedContentValueKind: ...
    @winrt_commethod(7)
    def get_Path(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_String(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(10)
    def get_Number(self) -> Double: ...
    @winrt_commethod(11)
    def get_Boolean(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_File(self) -> win32more.Windows.Services.TargetedContent.TargetedContentFile: ...
    @winrt_commethod(13)
    def get_ImageFile(self) -> win32more.Windows.Services.TargetedContent.TargetedContentImage: ...
    @winrt_commethod(14)
    def get_Action(self) -> win32more.Windows.Services.TargetedContent.TargetedContentAction: ...
    @winrt_commethod(15)
    def get_Strings(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(16)
    def get_Uris(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.Uri]: ...
    @winrt_commethod(17)
    def get_Numbers(self) -> win32more.Windows.Foundation.Collections.IVectorView[Double]: ...
    @winrt_commethod(18)
    def get_Booleans(self) -> win32more.Windows.Foundation.Collections.IVectorView[Boolean]: ...
    @winrt_commethod(19)
    def get_Files(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentFile]: ...
    @winrt_commethod(20)
    def get_ImageFiles(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentImage]: ...
    @winrt_commethod(21)
    def get_Actions(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentAction]: ...
    Action = property(get_Action, None)
    Actions = property(get_Actions, None)
    Boolean = property(get_Boolean, None)
    Booleans = property(get_Booleans, None)
    File = property(get_File, None)
    Files = property(get_Files, None)
    ImageFile = property(get_ImageFile, None)
    ImageFiles = property(get_ImageFiles, None)
    Number = property(get_Number, None)
    Numbers = property(get_Numbers, None)
    Path = property(get_Path, None)
    String = property(get_String, None)
    Strings = property(get_Strings, None)
    Uri = property(get_Uri, None)
    Uris = property(get_Uris, None)
    ValueKind = property(get_ValueKind, None)
class TargetedContentAction(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentAction
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentAction'
    @winrt_mixinmethod
    def InvokeAsync(self: win32more.Windows.Services.TargetedContent.ITargetedContentAction) -> win32more.Windows.Foundation.IAsyncAction: ...
class TargetedContentAppInstallationState(Enum, Int32):
    NotApplicable = 0
    NotInstalled = 1
    Installed = 2
class TargetedContentAvailability(Enum, Int32):
    None_ = 0
    Partial = 1
    All = 2
class TargetedContentAvailabilityChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentAvailabilityChangedEventArgs
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentAvailabilityChangedEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Services.TargetedContent.ITargetedContentAvailabilityChangedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class TargetedContentChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentChangedEventArgs
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentChangedEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Services.TargetedContent.ITargetedContentChangedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    @winrt_mixinmethod
    def get_HasPreviousContentExpired(self: win32more.Windows.Services.TargetedContent.ITargetedContentChangedEventArgs) -> Boolean: ...
    HasPreviousContentExpired = property(get_HasPreviousContentExpired, None)
class TargetedContentCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentCollection
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentCollection'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Services.TargetedContent.ITargetedContentCollection) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportInteraction(self: win32more.Windows.Services.TargetedContent.ITargetedContentCollection, interaction: win32more.Windows.Services.TargetedContent.TargetedContentInteraction) -> Void: ...
    @winrt_mixinmethod
    def ReportCustomInteraction(self: win32more.Windows.Services.TargetedContent.ITargetedContentCollection, customInteractionName: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Path(self: win32more.Windows.Services.TargetedContent.ITargetedContentCollection) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Services.TargetedContent.ITargetedContentCollection) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Services.TargetedContent.TargetedContentValue]: ...
    @winrt_mixinmethod
    def get_Collections(self: win32more.Windows.Services.TargetedContent.ITargetedContentCollection) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentCollection]: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Services.TargetedContent.ITargetedContentCollection) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentItem]: ...
    Collections = property(get_Collections, None)
    Id = property(get_Id, None)
    Items = property(get_Items, None)
    Path = property(get_Path, None)
    Properties = property(get_Properties, None)
class TargetedContentContainer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentContainer
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentContainer'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Services.TargetedContent.ITargetedContentContainer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Timestamp(self: win32more.Windows.Services.TargetedContent.ITargetedContentContainer) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_Availability(self: win32more.Windows.Services.TargetedContent.ITargetedContentContainer) -> win32more.Windows.Services.TargetedContent.TargetedContentAvailability: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.Services.TargetedContent.ITargetedContentContainer) -> win32more.Windows.Services.TargetedContent.TargetedContentCollection: ...
    @winrt_mixinmethod
    def SelectSingleObject(self: win32more.Windows.Services.TargetedContent.ITargetedContentContainer, path: WinRT_String) -> win32more.Windows.Services.TargetedContent.TargetedContentObject: ...
    @winrt_classmethod
    def GetAsync(cls: win32more.Windows.Services.TargetedContent.ITargetedContentContainerStatics, contentId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.TargetedContent.TargetedContentContainer]: ...
    Availability = property(get_Availability, None)
    Content = property(get_Content, None)
    Id = property(get_Id, None)
    Timestamp = property(get_Timestamp, None)
TargetedContentContract: UInt32 = 65536
class TargetedContentFile(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Streams.IRandomAccessStreamReference
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentFile'
    @winrt_mixinmethod
    def OpenReadAsync(self: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType]: ...
class TargetedContentImage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentImage
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentImage'
    @winrt_mixinmethod
    def get_Height(self: win32more.Windows.Services.TargetedContent.ITargetedContentImage) -> UInt32: ...
    @winrt_mixinmethod
    def get_Width(self: win32more.Windows.Services.TargetedContent.ITargetedContentImage) -> UInt32: ...
    @winrt_mixinmethod
    def OpenReadAsync(self: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType]: ...
    Height = property(get_Height, None)
    Width = property(get_Width, None)
class TargetedContentInteraction(Enum, Int32):
    Impression = 0
    ClickThrough = 1
    Hover = 2
    Like = 3
    Dislike = 4
    Dismiss = 5
    Ineligible = 6
    Accept = 7
    Decline = 8
    Defer = 9
    Canceled = 10
    Conversion = 11
    Opportunity = 12
class TargetedContentItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentItem
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentItem'
    @winrt_mixinmethod
    def get_Path(self: win32more.Windows.Services.TargetedContent.ITargetedContentItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportInteraction(self: win32more.Windows.Services.TargetedContent.ITargetedContentItem, interaction: win32more.Windows.Services.TargetedContent.TargetedContentInteraction) -> Void: ...
    @winrt_mixinmethod
    def ReportCustomInteraction(self: win32more.Windows.Services.TargetedContent.ITargetedContentItem, customInteractionName: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Services.TargetedContent.ITargetedContentItem) -> win32more.Windows.Services.TargetedContent.TargetedContentItemState: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Services.TargetedContent.ITargetedContentItem) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Services.TargetedContent.TargetedContentValue]: ...
    @winrt_mixinmethod
    def get_Collections(self: win32more.Windows.Services.TargetedContent.ITargetedContentItem) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentCollection]: ...
    Collections = property(get_Collections, None)
    Path = property(get_Path, None)
    Properties = property(get_Properties, None)
    State = property(get_State, None)
class TargetedContentItemState(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentItemState
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentItemState'
    @winrt_mixinmethod
    def get_ShouldDisplay(self: win32more.Windows.Services.TargetedContent.ITargetedContentItemState) -> Boolean: ...
    @winrt_mixinmethod
    def get_AppInstallationState(self: win32more.Windows.Services.TargetedContent.ITargetedContentItemState) -> win32more.Windows.Services.TargetedContent.TargetedContentAppInstallationState: ...
    AppInstallationState = property(get_AppInstallationState, None)
    ShouldDisplay = property(get_ShouldDisplay, None)
class TargetedContentObject(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentObject
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentObject'
    @winrt_mixinmethod
    def get_ObjectKind(self: win32more.Windows.Services.TargetedContent.ITargetedContentObject) -> win32more.Windows.Services.TargetedContent.TargetedContentObjectKind: ...
    @winrt_mixinmethod
    def get_Collection(self: win32more.Windows.Services.TargetedContent.ITargetedContentObject) -> win32more.Windows.Services.TargetedContent.TargetedContentCollection: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Windows.Services.TargetedContent.ITargetedContentObject) -> win32more.Windows.Services.TargetedContent.TargetedContentItem: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Services.TargetedContent.ITargetedContentObject) -> win32more.Windows.Services.TargetedContent.TargetedContentValue: ...
    Collection = property(get_Collection, None)
    Item = property(get_Item, None)
    ObjectKind = property(get_ObjectKind, None)
    Value = property(get_Value, None)
class TargetedContentObjectKind(Enum, Int32):
    Collection = 0
    Item = 1
    Value = 2
class TargetedContentStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentStateChangedEventArgs
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentStateChangedEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Services.TargetedContent.ITargetedContentStateChangedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class TargetedContentSubscription(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentSubscription'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetContentContainerAsync(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.TargetedContent.TargetedContentContainer]: ...
    @winrt_mixinmethod
    def add_ContentChanged(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.TargetedContent.TargetedContentSubscription, win32more.Windows.Services.TargetedContent.TargetedContentChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContentChanged(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_AvailabilityChanged(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.TargetedContent.TargetedContentSubscription, win32more.Windows.Services.TargetedContent.TargetedContentAvailabilityChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AvailabilityChanged(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.TargetedContent.TargetedContentSubscription, win32more.Windows.Services.TargetedContent.TargetedContentStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscription, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def GetAsync(cls: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionStatics, subscriptionId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.TargetedContent.TargetedContentSubscription]: ...
    @winrt_classmethod
    def GetOptions(cls: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionStatics, subscriptionId: WinRT_String) -> win32more.Windows.Services.TargetedContent.TargetedContentSubscriptionOptions: ...
    Id = property(get_Id, None)
    ContentChanged = event()
    AvailabilityChanged = event()
    StateChanged = event()
class TargetedContentSubscriptionOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionOptions
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentSubscriptionOptions'
    @winrt_mixinmethod
    def get_SubscriptionId(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AllowPartialContentAvailability(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_AllowPartialContentAvailability(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CloudQueryParameters(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionOptions) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def get_LocalFilters(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionOptions) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def Update(self: win32more.Windows.Services.TargetedContent.ITargetedContentSubscriptionOptions) -> Void: ...
    AllowPartialContentAvailability = property(get_AllowPartialContentAvailability, put_AllowPartialContentAvailability)
    CloudQueryParameters = property(get_CloudQueryParameters, None)
    LocalFilters = property(get_LocalFilters, None)
    SubscriptionId = property(get_SubscriptionId, None)
class TargetedContentValue(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.TargetedContent.ITargetedContentValue
    _classid_ = 'Windows.Services.TargetedContent.TargetedContentValue'
    @winrt_mixinmethod
    def get_ValueKind(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Services.TargetedContent.TargetedContentValueKind: ...
    @winrt_mixinmethod
    def get_Path(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_String(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Number(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> Double: ...
    @winrt_mixinmethod
    def get_Boolean(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> Boolean: ...
    @winrt_mixinmethod
    def get_File(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Services.TargetedContent.TargetedContentFile: ...
    @winrt_mixinmethod
    def get_ImageFile(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Services.TargetedContent.TargetedContentImage: ...
    @winrt_mixinmethod
    def get_Action(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Services.TargetedContent.TargetedContentAction: ...
    @winrt_mixinmethod
    def get_Strings(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_Uris(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.Uri]: ...
    @winrt_mixinmethod
    def get_Numbers(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Foundation.Collections.IVectorView[Double]: ...
    @winrt_mixinmethod
    def get_Booleans(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Foundation.Collections.IVectorView[Boolean]: ...
    @winrt_mixinmethod
    def get_Files(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentFile]: ...
    @winrt_mixinmethod
    def get_ImageFiles(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentImage]: ...
    @winrt_mixinmethod
    def get_Actions(self: win32more.Windows.Services.TargetedContent.ITargetedContentValue) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.TargetedContent.TargetedContentAction]: ...
    Action = property(get_Action, None)
    Actions = property(get_Actions, None)
    Boolean = property(get_Boolean, None)
    Booleans = property(get_Booleans, None)
    File = property(get_File, None)
    Files = property(get_Files, None)
    ImageFile = property(get_ImageFile, None)
    ImageFiles = property(get_ImageFiles, None)
    Number = property(get_Number, None)
    Numbers = property(get_Numbers, None)
    Path = property(get_Path, None)
    String = property(get_String, None)
    Strings = property(get_Strings, None)
    Uri = property(get_Uri, None)
    Uris = property(get_Uris, None)
    ValueKind = property(get_ValueKind, None)
class TargetedContentValueKind(Enum, Int32):
    String = 0
    Uri = 1
    Number = 2
    Boolean = 3
    File = 4
    ImageFile = 5
    Action = 6
    Strings = 7
    Uris = 8
    Numbers = 9
    Booleans = 10
    Files = 11
    ImageFiles = 12
    Actions = 13


make_ready(__name__)
